import { DataTypes, Model, Sequelize } from 'sequelize';
import { useContextKey } from '@kevisual/use-config/context';
import { SyncOpts } from './user.ts';
export class Org extends Model {
  declare id: string;
  declare username: string;
  declare description: string;
  declare users: { role: string; uid: string }[];
}
/**
 * 组织模型，在sequelize之后初始化
 */
export const OrgInit = (newSequelize?: any, tableName?: string, sync?: SyncOpts) => {
  const sequelize = useContextKey<Sequelize>('sequelize');
  Org.init(
    {
      id: {
        type: DataTypes.UUID,
        primaryKey: true,
        defaultValue: DataTypes.UUIDV4,
      },
      username: {
        type: DataTypes.STRING,
        allowNull: false,
        unique: true,
      },
      description: {
        type: DataTypes.STRING,
        allowNull: true,
      },
      users: {
        type: DataTypes.JSONB,
        allowNull: true,
        defaultValue: [],
      },
    },
    {
      sequelize: newSequelize || sequelize,
      modelName: tableName || 'cf_org',
      paranoid: true,
    },
  );
  if (sync) {
    Org.sync({ alter: true, logging: false, ...sync }).catch((e) => {
      console.error('Org sync', e);
    });
    return Org;
  }
  return Org;
};
useContextKey('OrgModel', () => Org);
